@@ -169,18 +169,18 @@ def SaveExcel(filename, data, Excel_head):
 
 
 html_clean = lambda text: re.sub(r'<[^>]+>', '', text)
-"""
-传入文本  -->  输出清除HTML标签后的文本
-:param text: Type == str
-:return: new text
-"""
+# """
+# 传入文本  -->  输出清除HTML标签后的文本
+# :param text: Type == str
+# :return: new text
+# """
 
 filename_clean = lambda filename: re.sub(r"[\/\\\:\*\?\"\<\>\|]", "_", filename)
-"""
-传入文本 --> 输出清除文件名非法字符后的文本
-:param filename: Type == str
-:return: new name
-"""
+# """
+# 传入文本 --> 输出清除文件名非法字符后的文本
+# :param filename: Type == str
+# :return: new name
+# """
 
 
 def SaveExcels(file_name, data, sheet, Excel_head):
@@ -481,6 +481,7 @@ retur: Node, the front page display text data
 
 def html_nodes_text(XPATH_list):
     """
+    该方法不完全等同于etree的//text()方法，实际应用场景请自行对比使用
     :param XPATH_list: Type == list 传入Xpath匹配到的节点群
     :return: Type == list 返回清洗后HTML标签后的文本
     """
@@ -491,7 +492,7 @@ def html_nodes_text(XPATH_list):
     return text_list
 
 
-def console(self, *args, sep=' ', end='\n', file=None, color=None, model=True, colorful=False):
+def console(self='', *args, sep=' ', end='\n', file=None, color=None, model=True, colorful=False):
     """
 
     :param self:
@@ -551,7 +552,6 @@ def mini_dom(node_list, title='The DOM tree reconstruction', sep='<p>\n*********
     for node in node_list:
         node_to_html = str(etree.tostring(node)).lstrip("b'").rstrip("'").replace(r'\n', '\n')
         all_html_nodes.append(node_to_html)
-    # <!-- -->
     node_to_html = sep.join(all_html_nodes)
     dom = html.unescape(f"""
             <!--JR-->
@@ -572,3 +572,35 @@ def mini_dom(node_list, title='The DOM tree reconstruction', sep='<p>\n*********
 re = re
 
 etree = etree
+
+def Incomplete_clearance(text, split_string):
+    """
+    All specified strings are cleared and then aggregated to remove n-1 units of a certain string.
+    :param text: Type == str
+    :param split_string: Type == str
+    :return: new_text: Type == str
+    """
+    text = text.split(split_string)
+    while True:
+        try:
+            text.remove('')
+        except:
+            break
+    new_text = split_string.join(text)
+    return new_text
+
+
+occurrences = lambda text, string :len(re.findall(string, text, re.S))
+# """
+# Counts how often a string appears in the text.
+# :param text: Type == str
+# :param string: Type == str
+# :return: num Type == int
+# """
+
+def cooKIE(cookie):
+    cookie_dic = {}
+    for i in cookie.split('; '):
+        cookie_dic[i.split('=')[0]] = i.split('=')[1]
+    return cookie_dic
+
